#include "nist.h"

int
    check_dst = 0,                  /* don't check for DST  */
    display = 0,                    /* display the received time */
    minus = 0,                      /* neg. timeadjust */
    dh = 0,                         /* delta hours */
    dm = 0,                         /* delta minutes */
    ds = 0,                         /* delta seconds */
    quiet = 0,                      /* run quietly */
    time_update = 0,                /* update the time */
    yy,                             /* retrieved time info */
    mo,
    dd,
    hh,
    mm,
    ss;

char
    *host = TIME_SERVER;            /* set the default server */

struct tm
    local;
