#include <stdio.h>

/*
    Note: the arguments follow the ordering of the display.
*/

void copyright(char const *progname, char const *author,
            char const *function,
            char const *version, char const *year)
{
    printf
    (
        "\n"
        "%s by %s.\n"
        "\n"
	"ICCE %s  V %s.\n"
        "Copyright(c) ICCE %s. All rights reserved.\n"
        "\n",
        progname,
        author,
        function,
        version,
        year
    );
}

