/*                              nist.c

   A C++ main()-frame generated by cpp.im for nist.c

*/

#include "nist.h"                           /* program header file */


int main(int argc, char **argv, char **envp)
{
    if (argc == 1)                          /* no arguments ?               */
        usage(argv[0]);                     /* then provide usage info      */

    options(argc, argv);                    /* process any options          */

    query_server();                         /* ask the server for the time */

    local_time();                           /* compute local time if the    */
                                            /* -a hh:mm:ss parameter was    */
                                            /* given                        */

    set_time();                             /* set the system time          */

    return (0);
}
